R/fit_gamma_distribution.R
fit_gamma_distribution.RdFind gamma distribution parameters to match a point estimate and confidence interval
fit_gamma_distribution( mean, lower, upper, confidence_level = 0.95, gamma_shape_range = c(0, 1000) )
| mean | The point estimate |
|---|---|
| lower | The lower confidence limit |
| upper | The upper confidence limit |
| confidence_level | The coverage probability of the confidence interval |
| gamma_shape_range | The range of gamma (shape) parameter values to search over (if insufficient, an error will be produced). |
a vector containing the estimated shape and scale parameters